@@ -1,4 +1,4 @@
-## ---- echo=FALSE, include=FALSE-----------------------------------------------
+## ----echo=FALSE, include=FALSE------------------------------------------------
 library(heemod)
 library(ggplot2)
 
@@ -8,7 +8,7 @@ param <- define_parameters(
     sex = 0,
     
     # age increases with cycles
-    age = age_init + markov_cycle,
+    age = age_init + model_time,
     
     # operative mortality rates
     omrPTHR = .02,
@@ -27,14 +27,14 @@ param <- define_parameters(
     rrNP1 = .260677,
     
     # revision probability of primary procedure
-    standardRR = 1 - exp(lambda * ((markov_cycle - 1) ^ gamma -
-                                     markov_cycle ^ gamma)),
-    np1RR = 1 - exp(lambda * rrNP1 * ((markov_cycle - 1) ^ gamma - 
-                                        markov_cycle ^ gamma)),
+    standardRR = 1 - exp(lambda * ((model_time - 1) ^ gamma -
+                                     model_time ^ gamma)),
+    np1RR = 1 - exp(lambda * rrNP1 * ((model_time - 1) ^ gamma - 
+                                        model_time ^ gamma)),
     
     # age-related mortality rate
     sex_cat = ifelse(sex == 0, "FMLE", "MLE"),
-    mr = get_who_mr(age, sex_cat, country = "GBR", local = TRUE),
+    mr = get_who_mr(age, sex_cat, local = TRUE),
     
     # state values
     u_SuccessP = .85,
@@ -77,7 +77,7 @@ mat_np1 <- define_transition(
 )
 mat_np1
 
-## ---- fig.width = 6, fig.height=6, fig.align='center'-------------------------
+## ----fig.width = 6, fig.height=6, fig.align='center'--------------------------
 plot(mat_standard)
 
 ## -----------------------------------------------------------------------------
@@ -150,7 +150,7 @@ res_mod <- run_model(
 ## -----------------------------------------------------------------------------
 summary(res_mod)
 
-## ---- fig.width = 6, fig.height=6, fig.align='center'-------------------------
+## ----fig.width = 6, fig.height=6, fig.align='center'--------------------------
 plot(res_mod, type = "counts", panel = "by_state", free_y = TRUE) +
   theme_bw() +
   scale_color_brewer(
