@@ -1,7 +1,7 @@
-## ---- echo=FALSE, include=FALSE-----------------------------------------------
+## ----echo=FALSE, include=FALSE------------------------------------------------
 library(heemod)
 
-## ---- define, include = FALSE-------------------------------------------------
+## ----define, include = FALSE--------------------------------------------------
 param <- define_parameters(
     age_init = 60,
     sex = 0,
@@ -131,7 +131,7 @@ res_mod <- run_model(
 
 ## ----get_counts, message=FALSE------------------------------------------------
 library(dplyr)
-get_counts(res_mod) %>% 
+get_counts(res_mod) |> 
   dplyr::filter(model_time == 20 & state_names == "RevisionTHR")
 
 ## ----extract_values-----------------------------------------------------------
