@@ -1,6 +1,6 @@
 param <- define_parameters(
   age_start = 60,
-  age = age_start + markov_cycle
+  age = age_start + model_time
 )
 
 heemod:::eval_parameters(param, cycles = 15)
