@@ -1,6 +1,3 @@
-context("Probabilistic analysis")
-
-
 test_that(
   "Probabilistic analysis works", {
     mod1 <-
@@ -41,7 +38,7 @@ test_that(
       parameters = define_parameters(
         age_init = 60,
         cost_init = 1000,
-        age = age_init + markov_cycle
+        age = age_init + model_time
       ),
       init = 1:0,
       cycles = 10,
@@ -67,8 +64,8 @@ test_that(
       correlation = define_correlation(age_init, cost_init, .4)
     )
     
-    rsp2_lazy <- define_psa_(
-      lazyeval::lazy_dots(
+    rsp2_tidy <- define_psa_(
+      rlang::quos(
         age_init ~ normal(60, 10),
         cost_init ~ normal(1000, 100)
       ),
@@ -77,7 +74,8 @@ test_that(
     
     expect_equal(
       rsp2, 
-      rsp2_lazy
+      rsp2_tidy,
+      ignore_function_env = TRUE
     )
     set.seed(1)
     # with run_model result
@@ -99,8 +97,8 @@ test_that(
       a + b ~ multinomial(15, 30)
     )
     
-    x_lazy <- define_psa_(
-      lazyeval::lazy_dots(
+    x_tidy <- define_psa_(
+      rlang::quos(
         rate1 + rate2 + rate3 ~ multinomial(10, 50, 40),
         a + b ~ multinomial(15, 30)
       )
@@ -108,12 +106,13 @@ test_that(
     
     expect_equal(
       x, 
-      x_lazy
+      x_tidy,
+      ignore_function_env = TRUE
     )
     
     set.seed(1)
     
-    res2 <- heemod:::eval_resample(x, 2)
+    res2 <- eval_resample(x, 2)
     
     expect_equal(
       nrow(ndt2$psa), 2
@@ -175,7 +174,7 @@ test_that(
       parameters = define_parameters(
         age_init = 60,
         cost_init = 1000,
-        age = age_init + markov_cycle
+        age = age_init + model_time
       ),
       init = 1:0,
       cycles = 10,
